﻿using Syncfusion.SfChart.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Reflection.Emit;
using System.Text;

using Xamarin.Forms;

namespace StepLineMin_XFOrm
{
    public class Page1 : ContentPage
    {
        public static readonly DateTime minDate = new DateTime(2000, 1, 1, 0, 0, 0);

        public Page1()
        {
            SfChart chart = new SfChart() { Margin = 10, BackgroundColor = Color.Gray }; //, HeightRequest = 100, VerticalOptions = LayoutOptions.Start };
            
            chart.SecondaryAxis = new NumericalAxis() { Interval = 2, OpposedPosition = true };

            var yearAxis = new DateTimeAxis()
            {
                Minimum = minDate,
                Interval = 1,
                IntervalType = DateTimeIntervalType.Years,
                LabelStyle = new ChartAxisLabelStyle() { LabelFormat = "yyyy" },
            };

            var minuteAxis = new DateTimeAxis()
            {
                Minimum = minDate,
                Interval = 1,
                IntervalType = DateTimeIntervalType.Minutes,
                LabelStyle = new ChartAxisLabelStyle() { LabelFormat = "mm" },
            };

            //chart.PrimaryAxis = yearAxis;

            MyViewModel m = new MyViewModel();

            chart.Series.Add(new StepAreaSeries()
            {
                XAxis = yearAxis,
                ItemsSource = m.DataYears,
                XBindingPath = "Date",
                YBindingPath = "Height",
                Color = Color.Red,
                Opacity = 0.5,
            });

            chart.Series.Add(new StepAreaSeries()
            {
                XAxis = minuteAxis,
                ItemsSource = m.DataMinutes,
                XBindingPath = "Date",
                YBindingPath = "Height",
                Color = Color.Blue,
                Opacity = 0.5,
            });

            chart.Series.Add(new LineSeries()
            {
                XAxis = yearAxis,
                ItemsSource = m.DataYears,
                XBindingPath = "Date",
                YBindingPath = "Height",
                Color = Color.Black,
                StrokeWidth = 3,
            });

            chart.Series.Add(new LineSeries()
            {
                XAxis = minuteAxis,
                ItemsSource = m.DataMinutes,
                XBindingPath = "Date",
                YBindingPath = "Height",
                Color = Color.Yellow,
                StrokeWidth = 1,
            });

            this.Content = chart;
        }


    }

    public class Person
    {
        public double Name { get; set; }

        public double Height { get; set; }

        public DateTime Date { get; set; }

        public string System { get; set; }
    }

    public class MyViewModel
    {
        public ObservableCollection<Person> DataYears { get; set; }
        public ObservableCollection<Person> DataMinutes { get; set; }
        public MyViewModel()
        {

            DataYears = new ObservableCollection<Person>();
            DataMinutes = new ObservableCollection<Person>();

            DateTime date = Page1.minDate;
            Random rd = new Random();

            for (int i = 1; i < 35; i++)
            {
                bool hasValue = rd.Next() % 2 == 0;

                DataYears.Add(new Person() { Date = date.AddYears(i), Height = hasValue ? 2 : 0, Name = i });
                DataMinutes.Add(new Person() { Date = date.AddMinutes(i), Height = hasValue ? 1 : 0, Name = i });
            }
        }


    }
}
